log_error

Macro log_error 

macro_rules! log_error {
    ($expr:expr_2021) => { ... };
    ($expr:expr_2021, $message:expr_2021) => { ... };
}
A convenience macro for logging the contents of error variants.

This is useful when there is no further action required to process the error path, but you still want to record that it transpired