pub struct BoxedHandler(/* private fields */);Expand description
A type-erased handler
Implementations
Sourceimpl BoxedHandler
impl BoxedHandler
Sourcepub fn is<T: Any + 'static>(&self) -> bool
pub fn is<T: Any + 'static>(&self) -> bool
Determine if this BoxedHandler is the specified type
Sourcepub fn downcast<T: Any + 'static>(self) -> Result<T, Self>
pub fn downcast<T: Any + 'static>(self) -> Result<T, Self>
Attempt to transform this BoxedHandler into the specified type
Errors
Downcast returns the BoxedHandler as an error if it does not contain the provided type
Sourcepub fn downcast_ref<T: Any + 'static>(&self) -> Option<&T>
pub fn downcast_ref<T: Any + 'static>(&self) -> Option<&T>
Attempt to borrow this BoxedHandler as the provided type, returning None if it does not
contain the type
Sourcepub fn downcast_mut<T: Any + 'static>(&mut self) -> Option<&mut T>
pub fn downcast_mut<T: Any + 'static>(&mut self) -> Option<&mut T>
Attempt to mutably borrow this BoxedHandler as the provided type, returning None if it
does not contain the type