Struct Headers
pub struct Headers { /* private fields */ }Expand description
Trillium’s header map type
Implementations
impl Headers
impl Headers
pub fn iter(&self) -> Iter<'_> ⓘ
pub fn iter(&self) -> Iter<'_> ⓘ
Return an iterator over borrowed header names and header values. First yields the known headers and then the unknown headers, if any.
pub fn len(&self) -> usize
pub fn len(&self) -> usize
How many unique HeaderName have been added to these Headers?
Note that each header name may have more than one HeaderValue.
pub fn append(
&mut self,
name: impl Into<HeaderName<'static>>,
values: impl Into<HeaderValues>,
) -> &mut HeaderValues
pub fn append( &mut self, name: impl Into<HeaderName<'static>>, values: impl Into<HeaderValues>, ) -> &mut HeaderValues
add the header value or header values into this header map. If
there is already a header with the same name, the new values
will be added to the existing ones. To replace any existing
values, use Headers::insert
Identical to headers.entry(name).append(values)
pub fn append_all(&mut self, other: Headers)
pub fn append_all(&mut self, other: Headers)
pub fn insert_all(&mut self, other: Headers)
pub fn insert_all(&mut self, other: Headers)
Combine two Headers, replacing any existing header values
pub fn insert(
&mut self,
name: impl Into<HeaderName<'static>>,
values: impl Into<HeaderValues>,
) -> &mut Headers
pub fn insert( &mut self, name: impl Into<HeaderName<'static>>, values: impl Into<HeaderValues>, ) -> &mut Headers
Add a header value or header values into this header map. If a
header already exists with the same name, it will be
replaced. To combine, see Headers::append
pub fn try_insert(
&mut self,
name: impl Into<HeaderName<'static>>,
values: impl Into<HeaderValues>,
) -> &mut Headers
pub fn try_insert( &mut self, name: impl Into<HeaderName<'static>>, values: impl Into<HeaderValues>, ) -> &mut Headers
Add a header value or header values into this header map if and only if there is not already a header with the same name.
Identical to headers.entry(name).or_insert(default)
pub fn try_insert_with<V>(
&mut self,
name: impl Into<HeaderName<'static>>,
values: impl FnOnce() -> V,
) -> &mut HeaderValueswhere
V: Into<HeaderValues>,
pub fn try_insert_with<V>(
&mut self,
name: impl Into<HeaderName<'static>>,
values: impl FnOnce() -> V,
) -> &mut HeaderValueswhere
V: Into<HeaderValues>,
if a key does not exist already, execute the provided function and insert a value
Identical to
headers.entry(name).or_insert_with(values)
pub fn entry(&mut self, name: impl Into<HeaderName<'static>>) -> Entry<'_>
pub fn entry(&mut self, name: impl Into<HeaderName<'static>>) -> Entry<'_>
Return a view into the entry for this header name, whether or not it is populated.
See also Entry
pub fn get_str<'a>(&self, name: impl Into<HeaderName<'a>>) -> Option<&str>
pub fn get_str<'a>(&self, name: impl Into<HeaderName<'a>>) -> Option<&str>
Retrieves a &str header value if there is at least one header
in the map with this name. If there are several headers with
the same name, this follows the behavior defined at
HeaderValues::one. Returns None if there is no header with
the provided header name.
pub fn get<'a>(&self, name: impl Into<HeaderName<'a>>) -> Option<&HeaderValue>
pub fn get<'a>(&self, name: impl Into<HeaderName<'a>>) -> Option<&HeaderValue>
Retrieves a singular header value from this header map. If there are several headers with
the same name, this follows the behavior defined at HeaderValues::one. Returns None if
there is no header with the provided header name
pub fn remove<'a>(
&mut self,
name: impl Into<HeaderName<'a>>,
) -> Option<HeaderValues>
pub fn remove<'a>( &mut self, name: impl Into<HeaderName<'a>>, ) -> Option<HeaderValues>
Takes all headers with the provided header name out of this header map and returns them. Returns None if the header did not have an entry in this map.
pub fn get_values<'a>(
&self,
name: impl Into<HeaderName<'a>>,
) -> Option<&HeaderValues>
pub fn get_values<'a>( &self, name: impl Into<HeaderName<'a>>, ) -> Option<&HeaderValues>
Retrieves a reference to all header values with the provided
header name. If you expect there to be only one value, use
Headers::get.
pub fn has_header<'a>(&self, name: impl Into<HeaderName<'a>>) -> bool
pub fn has_header<'a>(&self, name: impl Into<HeaderName<'a>>) -> bool
Predicate function to check whether this header map contains
the provided header name. If you are using this to
conditionally insert a value, consider using
Headers::try_insert instead.
pub fn eq_ignore_ascii_case<'a>(
&'a self,
name: impl Into<HeaderName<'a>>,
needle: &str,
) -> bool
pub fn eq_ignore_ascii_case<'a>( &'a self, name: impl Into<HeaderName<'a>>, needle: &str, ) -> bool
Convenience function to check whether the value contained in this header map for the provided name is ascii-case-insensitively equal to the provided comparison &str. Returns false if there is no value for the name
pub fn with_inserted_header(
self,
name: impl Into<HeaderName<'static>>,
values: impl Into<HeaderValues>,
) -> Headers
pub fn with_inserted_header( self, name: impl Into<HeaderName<'static>>, values: impl Into<HeaderValues>, ) -> Headers
Chainable method to insert a header
pub fn with_appended_header(
self,
name: impl Into<HeaderName<'static>>,
values: impl Into<HeaderValues>,
) -> Headers
pub fn with_appended_header( self, name: impl Into<HeaderName<'static>>, values: impl Into<HeaderValues>, ) -> Headers
Chainable method to append a header
pub fn without_header<'a>(self, name: impl Into<HeaderName<'a>>) -> Headers
pub fn without_header<'a>(self, name: impl Into<HeaderName<'a>>) -> Headers
Chainable method to remove a header
pub fn without_headers<'a, I, H>(self, names: I) -> Headers
pub fn without_headers<'a, I, H>(self, names: I) -> Headers
Chainable method to remove multiple headers by name
pub fn remove_all<'a, I, H>(&mut self, names: I)
pub fn remove_all<'a, I, H>(&mut self, names: I)
remove multiple headers by name