pub struct Info(/* private fields */);Expand description
This struct represents information about the currently connected server.
It is passed to Handler::init.
Implementations
Sourceimpl Info
impl Info
Sourcepub fn tcp_socket_addr(&self) -> Option<&SocketAddr>
pub fn tcp_socket_addr(&self) -> Option<&SocketAddr>
Returns the local_addr of a bound tcp listener, if such a
thing exists for this server
Sourcepub fn unix_socket_addr(&self) -> Option<&SocketAddr>
pub fn unix_socket_addr(&self) -> Option<&SocketAddr>
Returns the local_addr of a bound unix listener, if such a
thing exists for this server
Borrow a type from the shared state TypeSet on this Info.
Insert a type into the shared state typeset, returning the previous value if any
Mutate a type in the shared state typeset
Returns an Entry into the shared state typeset.
chainable interface to insert a type into the shared state typeset
Sourcepub fn config(&self) -> &HttpConfig
pub fn config(&self) -> &HttpConfig
borrow the http config
Sourcepub fn config_mut(&mut self) -> &mut HttpConfig
pub fn config_mut(&mut self) -> &mut HttpConfig
mutate the http config